@@ -9,8 +9,8 @@ def casing():
     #Chama os pacotes usados no programa
     import math
    # import matplotlib.pyplot  #Necessário somente caso for construir o gráfico, entretanto o gráfico não é necessário
-    from RocketCasing import materials
-   #import materials
+   # from RocketCasing import materials #teste
+    import materials
     from datetime import datetime
 
 #Abertura do programa
@@ -45,9 +45,9 @@ def casing():
     print("-------------------------")
     print("Material: ", prop)
     print("Características do material: ", '{}'.format(p))
-    b=p['Fty']/p['Ftu']
+    b=p['Fty']/p['Ftu'] if p['Fty']!=0 or p['Ftu']!=0 else 0
     print("Razão da força do material: b= ",'{:.5f}'.format(b))
-    B=(9.5833*b**4)+(-33.528*b**3)+(44.929*b**2)+(-28.479*b)+8.6475
+    B=(9.5833*b**4)+(-33.528*b**3)+(44.929*b**2)+(-28.479*b)+8.6475 if b!=0 else 0
     print("Fator de ruptura: B= ",'{:.5f}'.format(B))
  
     if op=="0":
